@@ -51,29 +51,26 @@
 #'
 #' @examples
 #' # single variable
-#' extract(mtcars, cyl, name = gear)
-#' extract(mtcars, "cyl", name = gear)
-#' extract(mtcars, -1, name = gear)
-#' extract(mtcars, cyl, name = 0)
-#' extract(mtcars, cyl, name = "row.names")
+#' data_extract(mtcars, cyl, name = gear)
+#' data_extract(mtcars, "cyl", name = gear)
+#' data_extract(mtcars, -1, name = gear)
+#' data_extract(mtcars, cyl, name = 0)
+#' data_extract(mtcars, cyl, name = "row.names")
 #'
 #' # selecting multiple variables
-#' head(extract(iris, starts_with("Sepal")))
-#' head(extract(iris, ends_with("Width")))
-#' head(extract(iris, 2:4))
+#' head(data_extract(iris, starts_with("Sepal")))
+#' head(data_extract(iris, ends_with("Width")))
+#' head(data_extract(iris, 2:4))
 #'
 #' # select first of multiple variables
-#' extract(iris, starts_with("Sepal"), extract = "first")
+#' data_extract(iris, starts_with("Sepal"), extract = "first")
+#'
 #' # select first of multiple variables, return as data frame
-#' head(extract(iris, starts_with("Sepal"), extract = "first", as_data_frame = TRUE))
+#' head(data_extract(iris, starts_with("Sepal"), extract = "first", as_data_frame = TRUE))
 data_extract <- function(data, select, ...) {
   UseMethod("data_extract")
 }
 
-#' @export
-#' @rdname data_extract
-extract <- data_extract
-
 #' @rdname data_extract
 #' @export
 data_extract.data.frame <- function(data,
