@@ -151,7 +151,8 @@ standardize.numeric <- function(x,
   args <- .process_std_center(x, weights, robust, verbose, reference, center, scale)
 
   # Perform standardization
-  if (is.null(args)) { # all NA?
+  if (is.null(args)) {
+    # all NA?
     return(x)
   } else if (is.null(args$check)) {
     vals <- rep(0, length(args$vals)) # If only unique value
